@@ -11,11 +11,11 @@ from collections.abc import Sequence
 #
 # FIXME (#2324): this sucks, we should re-organise this and not rely on "lifting"
 # this functions this way
-from pmb.config.file import load, save, serialize
+from pmb.config.file import load as load, save as save, serialize as serialize
 from pmb.config.sudo import which_sudo
-from pmb.config.other import is_systemd_selected
-from .init import require_programs
-from . import workdir
+from pmb.config.other import is_systemd_selected as is_systemd_selected
+from .init import require_programs as require_programs
+from . import workdir as workdir
 
 
 #
@@ -30,8 +30,9 @@ apk_keys_path: Path = pmb_src / "pmb/data/keys"
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
 apk_tools_min_version = {
-    "edge": "2.14.9-r0",
-    "v3.21": "2.14.6-r2",
+    "edge": "2.14.9-r3",
+    "v3.22": "2.14.9-r2",
+    "v3.21": "2.14.6-r3",
     "v3.20": "2.14.4-r1",
     "v3.19": "2.14.4-r0",
     "v3.18": "2.14.4-r0",
@@ -104,6 +105,7 @@ styles = {
     "BLUE": "\033[94m",
     "BOLD": "\033[1m",
     "GREEN": "\033[92m",
+    "MAGENTA": "\033[95m",
     "RED": "\033[91m",
     "YELLOW": "\033[93m",
     "END": "\033[0m",
@@ -222,7 +224,7 @@ chroot_outdated = 3600 * 24 * 2
 # NOTE: full hexdump is installed to workaround a bug in busybox,
 # see https://gitlab.postmarketos.org/postmarketOS/pmaports/-/issues/3268. This can be
 # reverted when the bug is properly fixed.
-build_packages = ["abuild", "apk-tools", "build-base", "ccache", "git", "hexdump"]
+build_packages = ["abuild", "apk-tools", "build-base", "ccache", "git", "hexdump", "pigz"]
 
 #
 # PARSE
@@ -301,7 +303,9 @@ apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
     "!pmb:kconfigcheck",
     "pmb:cross-native",
-    "pmb:gpu-accel",
+    "pmb:cross-native2",
+    "pmb:drm",
+    "pmb:gpu-accel",  # deprecated
     "pmb:strict",
     "pmb:systemd",
     "pmb:systemd-never",
