@@ -120,6 +120,14 @@ def arguments_install(subparser: argparse._SubParsersAction) -> None:
         choices=[512, 2048, 4096],
     )
 
+    ret.add_argument(
+        "--single-partition",
+        action="store_true",
+        help="Create a single partition that contains both boot and root files."
+        " This can be used on devices that boot without mounting the boot file"
+        " system (e.g. Android boot images or fastboot).",
+    )
+
     # Image type
     group_desc = ret.add_argument_group(
         "optional image type",
@@ -721,15 +729,6 @@ def arguments_kconfig(subparser: argparse._SubParsersAction) -> None:
     add_kernel_arg(migrate, nargs=1)
 
 
-def arguments_repo_bootstrap(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
-    arch_choices = Arch.supported()
-
-    ret = subparser.add_parser("repo_bootstrap")
-    ret.add_argument("repository", help="which repository to bootstrap (e.g. systemd)")
-    ret.add_argument("--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x))
-    return ret
-
-
 def arguments_repo_missing(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
         "repo_missing",
@@ -977,7 +976,6 @@ def get_parser() -> argparse.ArgumentParser:
         " non-interactively to migrate the"
         " work folder version on demand",
     )
-    arguments_repo_bootstrap(sub)
     arguments_repo_missing(sub)
     arguments_kconfig(sub)
     arguments_export(sub)
@@ -1102,6 +1100,12 @@ def get_parser() -> argparse.ArgumentParser:
         help="Mount the rootfs image and treat it like a normal chroot.",
         action="store_true",
     )
+    chroot.add_argument(
+        "--usb",
+        help="Make USB devices accessible inside the chroot.",
+        action="store_true",
+        dest="chroot_usb",
+    )
     chroot.add_argument(
         "command",
         default=["sh", "-i"],
